<!DOCTYPE TS><TS>
<context>
    <name>Wizard</name>
    <message>
        <source>Kadu Wizard</source>
        <translation>Créateur configuration Kadu</translation>
    </message>
    <message>
        <source>I have a number</source>
        <translation>J&apos;ai possède déjà le numéro</translation>
    </message>
    <message>
        <source>Gadu-gadu number</source>
        <translation>Numéro GG</translation>
    </message>
    <message>
        <source>Gadu-gadu password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <source>Import contacts</source>
        <translation>Importation de contacts</translation>
    </message>
    <message>
        <source>Your e-mail address</source>
        <translation>Adresse e-mail</translation>
    </message>
    <message>
        <source>Choose your browser</source>
        <translation>Choix de navigateur</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Données erronées.
Le mot de passe devrait être le même (&quot;nouveau mot de passe&quot; et &quot;retappez le nouveau mot de passe&quot; dans les deux champs!</translation>
    </message>
    <message>
        <source>An error has occured while registration. Please try again later.</source>
        <translation>Erreur lors d&apos;enregistrement.Veuillez essayer plus tard.</translation>
    </message>
    <message>
        <source>User list wasn&apos;t imported because of some error</source>
        <translation>Erreur d&apos;importation de la liste de contacts</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Enregistrement</translation>
    </message>
    <message>
        <source>Registration was successful.
You UIN is: </source>
        <translation>Enregistrement avec success.
Votre VIN numero Kadu est :</translation>
    </message>
    <message>
        <source>
Account configuration was saved.
Press Ok to continue</source>
        <translation>Votre configuration a été enregistrée.
Appuyer suivant pour continuer</translation>
    </message>
    <message>
        <source>Please fill out all fields</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email address you have entered is not valid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I don&apos;t have a number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retype password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Specify path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Konqueror</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opera</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mozilla</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mozilla Firefox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dillo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Galeon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Safari</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose your e-mail client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KMail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Thunderbird</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SeaMonkey</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Evolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom e-mail client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;Please setup Kadu for working with your favourite WWW browser and email program.&lt;/p&gt;&lt;p&gt;Kadu will use these for opening various links from messages and user&apos;s descriptions&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;Please select your sound driver for sound notifications. If you don&apos;t want sound notifications, use None driver.&lt;/p&gt;&lt;p&gt;If you don&apos;t know which driver to use, just check every ony with Test sound button.Don&apos;t forget to unmute your system before!&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;h3&gt;Welcome in Kadu&lt;/h3&gt;&lt;h4&gt;the Gadu-gadu network client for *nix and MacOS X.&lt;/h4&gt;&lt;p&gt;This is first time you launch Kadu. This wizard will help you to configure the basic settings of Kadu. If you are experienced Kadu user you may omit the wizard by clicking Cancel.&lt;/p&gt;&lt;p&gt;Please enter your account data. If you don&apos;t have one, you can create new here.&lt;/p&gt;&lt;p&gt;E-mail address is needed when you want to recover lost password to account&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gadu-gadu account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opera (new tab)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WizardStarter</name>
    <message>
        <source>Configuration Wizard</source>
        <translation>Créateur de configuration</translation>
    </message>
    <message>
        <source>User list couldn&apos;t be imported</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
